import { Problem, ThinkingStep } from '../types/debug.js';
import { SearchQuery } from '../types/search.js';
import { StartParams, ThinkParams, ExperimentParams, ObserveParams, SearchParams } from '../types/actions.js';
export declare class DebugServer {
    private debugSessions;
    private errorPatterns;
    private successfulFixes;
    private currentSessionId;
    private dataDir;
    private searchIndex;
    constructor();
    initialize(): Promise<void>;
    private initializeStorage;
    private loadKnowledge;
    private loadSessionsIntoIndex;
    private saveKnowledge;
    private countSessions;
    private saveSession;
    private generateId;
    private learnFromResult;
    startSession(sessionId?: string, problem?: Problem, metadata?: {
        language?: string;
        framework?: string;
        tags?: string[];
    }): string;
    recordStep(input: unknown): Promise<{
        content: Array<{
            type: string;
            text: string;
        }>;
        isError?: boolean;
    }>;
    getSessionSummary(sessionId?: string): Promise<{
        content: Array<{
            type: string;
            text: string;
        }>;
    }>;
    endSession(sessionId?: string): Promise<{
        content: Array<{
            type: string;
            text: string;
        }>;
    }>;
    listSessions(): Promise<{
        content: Array<{
            type: string;
            text: string;
        }>;
    }>;
    searchPatterns(query: SearchQuery): {
        content: Array<{
            type: string;
            text: string;
        }>;
    };
    getActiveSessionIds(): string[];
    saveAllKnowledge(): Promise<void>;
    recordThinking(sessionId: string | undefined, thinkingSteps: ThinkingStep[]): {
        content: Array<{
            type: string;
            text: string;
        }>;
        isError?: boolean;
    };
    convertThinkingToHypothesis(sessionId: string | undefined, thinkingConclusion: string, confidence?: number): {
        content: Array<{
            type: string;
            text: string;
        }>;
        isError?: boolean;
    };
    start(params: StartParams): {
        content: Array<{
            type: string;
            text: string;
        }>;
    };
    think(params: ThinkParams): {
        content: Array<{
            type: string;
            text: string;
        }>;
    };
    experiment(params: ExperimentParams): {
        content: Array<{
            type: string;
            text: string;
        }>;
    };
    observe(params: ObserveParams): Promise<{
        content: Array<{
            type: string;
            text: string;
        }>;
    }>;
    search(params: SearchParams): {
        content: Array<{
            type: string;
            text: string;
        }>;
    };
    end(summary?: boolean): Promise<{
        content: Array<{
            type: string;
            text: string;
        }>;
    }>;
}
//# sourceMappingURL=DebugServer.d.ts.map