import { Node, Edge, DebugGraph } from '../types/graph.js';
/**
 * グラフデータの永続化を担当するストレージクラス
 * JSONL形式でノードとエッジを追記保存し、メタデータはJSONで保存
 * データディレクトリ: ~/.debug-thinking-mcp/
 */
export declare class GraphStorage {
    private dataDir;
    private nodesFile;
    private edgesFile;
    private metadataFile;
    /**
     * ストレージパスを初期化
     * 環境変数DEBUG_DATA_DIRが設定されていればそれを使用
     * 指定がなければカレントディレクトリ（MCPを呼び出すプロジェクトのルート）に保存
     */
    constructor();
    /**
     * ストレージディレクトリを作成して初期化
     * ディレクトリが存在しない場合は再帰的に作成
     */
    initialize(): Promise<void>;
    saveNode(node: Node): Promise<void>;
    /**
     * エッジをJSONLファイルに追記保存
     * メタデータが存在する場合のみ日付を変換
     */
    saveEdge(edge: Edge): Promise<void>;
    /**
     * グラフメタデータをJSONファイルに保存
     * ルートノードリストとノード/エッジ数も記録
     * 毎回上書き保存（追記ではない）
     */
    saveGraphMetadata(graph: DebugGraph): Promise<void>;
    /**
     * 保存されたグラフデータを読み込み
     * JSONLファイルからノードとエッジを復元し、Map構造を再構築
     * 重複データは最新のものを保持
     * @returns 復元されたグラフまたはnull(データがない場合)
     */
    loadGraph(): Promise<DebugGraph | null>;
    /**
     * ストレージをクリア（テスト/リセット用）
     * TODO: 実装予定 - ファイル削除またはディレクトリクリア
     */
    clearStorage(): Promise<void>;
}
//# sourceMappingURL=GraphStorage.d.ts.map