import { ThinkingStep } from '../types/debug.js';
/**
 * Sequential Thinking Integration Helper
 *
 * This module provides utilities to integrate sequential-thinking MCP output
 * with debug-thinking-mcp for seamless debugging workflows.
 */
export interface SequentialThinkingOutput {
    thought: string;
    nextThoughtNeeded: boolean;
    thoughtNumber: number;
    totalThoughts: number;
    isRevision?: boolean;
    revisesThought?: number;
    branchFromThought?: number;
    branchId?: string;
}
/**
 * Convert sequential-thinking output to ThinkingStep format
 */
export declare function convertToThinkingStep(output: SequentialThinkingOutput): ThinkingStep;
/**
 * Extract conclusion from a series of thinking steps
 */
export declare function extractConclusion(steps: ThinkingStep[]): string;
/**
 * Estimate confidence based on thinking process
 */
export declare function estimateConfidence(steps: ThinkingStep[]): number;
/**
 * Generate a hypothesis cause from thinking steps
 */
export declare function generateHypothesisCause(steps: ThinkingStep[]): string;
/**
 * Suggest affected code areas based on thinking analysis
 */
export declare function suggestAffectedCode(steps: ThinkingStep[]): string[];
/**
 * Create a complete workflow from sequential thinking to hypothesis
 */
export interface ThinkingWorkflowResult {
    thinkingSteps: ThinkingStep[];
    hypothesis: {
        cause: string;
        affectedCode: string[];
        confidence: number;
        thoughtConclusion: string;
    };
    suggestedNextAction: 'iterate' | 'pivot' | 'research' | 'fixed';
}
export declare function createThinkingWorkflow(sequentialOutputs: SequentialThinkingOutput[]): ThinkingWorkflowResult;
//# sourceMappingURL=sequentialThinkingIntegration.d.ts.map